@@ -484,7 +484,7 @@ mod tests {
 
     #[test]
     fn parse_set_phase() {
-        let tokens = lex(r#"SET-PHASE 0 "rf" 1.0; SET-PHASE 0 1 "rf" theta"#);
+        let tokens = lex(r#"SET-PHASE 0 "rf" 1.0; SET-PHASE 0 1 "rf" theta"#).unwrap();
         let (remainder, parsed) = parse_instructions(&tokens).unwrap();
         let expected = vec![
             Instruction::SetPhase(SetPhase {
@@ -511,7 +511,7 @@ mod tests {
 
     #[test]
     fn parse_set_scale() {
-        let tokens = lex(r#"SET-SCALE 0 "rf" 1.0; SET-SCALE 0 1 "rf" theta"#);
+        let tokens = lex(r#"SET-SCALE 0 "rf" 1.0; SET-SCALE 0 1 "rf" theta"#).unwrap();
         let (remainder, parsed) = parse_instructions(&tokens).unwrap();
         let expected = vec![
             Instruction::SetScale(SetScale {
@@ -538,7 +538,7 @@ mod tests {
 
     #[test]
     fn parse_set_frequency() {
-        let tokens = lex(r#"SET-FREQUENCY 0 "rf" 1.0; SET-FREQUENCY 0 1 "rf" theta"#);
+        let tokens = lex(r#"SET-FREQUENCY 0 "rf" 1.0; SET-FREQUENCY 0 1 "rf" theta"#).unwrap();
         let (remainder, parsed) = parse_instructions(&tokens).unwrap();
         let expected = vec![
             Instruction::SetFrequency(SetFrequency {
@@ -565,7 +565,7 @@ mod tests {
 
     #[test]
     fn parse_shift_frequency() {
-        let tokens = lex(r#"SHIFT-FREQUENCY 0 "rf" 1.0; SHIFT-FREQUENCY 0 1 "rf" theta"#);
+        let tokens = lex(r#"SHIFT-FREQUENCY 0 "rf" 1.0; SHIFT-FREQUENCY 0 1 "rf" theta"#).unwrap();
         let (remainder, parsed) = parse_instructions(&tokens).unwrap();
         let expected = vec![
             Instruction::ShiftFrequency(ShiftFrequency {
@@ -592,7 +592,7 @@ mod tests {
 
     #[test]
     fn parse_shift_phase() {
-        let tokens = lex(r#"SHIFT-PHASE 0 "rf" 1.0; SHIFT-PHASE 0 1 "rf" theta"#);
+        let tokens = lex(r#"SHIFT-PHASE 0 "rf" 1.0; SHIFT-PHASE 0 1 "rf" theta"#).unwrap();
         let (remainder, parsed) = parse_instructions(&tokens).unwrap();
         let expected = vec![
             Instruction::ShiftPhase(ShiftPhase {
